import { FooterConfig, HomeConfig, NavItem } from './config/baseConfig'

export interface Config {
  title:string;
  homeConfig: HomeConfig
  hasDarkSwitch: boolean
  docRoot:string
  nav?: NavItem[]

  footer: FooterConfig

  /**
   * Algolia configuration for the site search.
   */
  algolia?: AlgoliaSearchOptions

  /**
   * CarbonAds configuration
   */
  carbonAds?: {
    code: string
    placement: string
  }

  /**
   * Translation/Locales links
   */
}

/**
 * The Algolia search options. Partially copied from
 * @docsearch/react/dist/esm/DocSearch.d.ts
 */
export interface AlgoliaSearchOptions {
  appId?: string
  apiKey: string
  indexName: string
  placeholder?: string
  searchParameters?: any
  disableUserPersonalization?: boolean
  initialQuery?: string
  translations?: Partial<DocSearchTranslations>
}

export interface DocSearchTranslations {
  button?: ButtonTranslations
  modal?: ModalTranslations
}

export interface ButtonTranslations {
  buttonText?: string
  buttonAriaLabel?: string
}
export interface ModalTranslations extends ScreenStateTranslations {
  searchBox?: {
    resetButtonTitle?: string
    resetButtonAriaLabel?: string
    cancelButtonText?: string
    cancelButtonAriaLabel?: string
  }
  footer?: {
    selectText?: string
    selectKeyAriaLabel?: string
    navigateText?: string
    navigateUpKeyAriaLabel?: string
    navigateDownKeyAriaLabel?: string
    closeText?: string
    closeKeyAriaLabel?: string
    searchByText?: string
  }
}
export interface ScreenStateTranslations {
  errorScreen?: {
    titleText?: string
    helpText?: string
  }
  startScreen?: {
    recentSearchesTitle?: string
    noRecentSearchesText?: string
    saveRecentSearchButtonTitle?: string
    removeRecentSearchButtonTitle?: string
    favoriteSearchesTitle?: string
    removeFavoriteSearchButtonTitle?: string
  }
  noResultsScreen?: {
    noResultsText?: string
    suggestedQueryText?: string
    reportMissingResultsText?: string
    reportMissingResultsLinkText?: string
  }
}
export interface MessageWithLink {
  before?: string
  link?: string
  after?: string
}
